#!/usr/bin/env Rscript

library(ape)
library(apTreeshape)
library(ggplot2)

source('../plot_common.R')

# Phylogenetic diversity
pd <- function(tr) sum(tr$edge.length)

main <- function(tree_file, bootstrap_file, target) {
  tree <- read.tree(tree_file)
  trees <- read.tree(bootstrap_file)
  stopifnot(length(trees) > 1)

  # PD
  tree_pd <- pd(tree)
  pds <- unlist(lapply(trees, pd))
  pd_df <- data.frame(pd=pds, rel_pd=pds/tree_pd)

  # colless
  tree_coll <- colless(tree)
  collesses <- unlist(lapply(trees, colless))
  coll_df <- data.frame(colless=collesses, rel_colless=collesses/tree_coll)

  pdf(target)
  p <- ggplot(pd_df, aes(x=rel_pd)) + geom_density() + geom_vline(xintercept=1) +
    xlab("Bootstrap PD / original PD") +
    annotate("text", x=.9, y=0.5, label=sprintf("%.1f%% < 1", sum(pds/tree_pd < 1)/length(pds)*100))
  print(p)
  #p <- ggplot(pd_df, aes(x=rel_pd)) + geom_density() + geom_vline(xintercept=1) +
    #xlab("Bootstrap PD / original PD") +
    #annotate("text", x=.9, y=0.5, label=sprintf("%.1f%% < 1", sum(pds/tree_pd < 1)/length(pds)*100))

  dev.off()
}

if (!interactive()) {
  args <- commandArgs(TRUE)
  stopifnot(length(args) == 3)
  tree_file <- args[1]
  bs_file <- args[2]
  target <- args[3]
  main(tree_file, bs_file, target)
}
